Re: [PATCH v2 0/7] Speed up mirror-fetches with many refs
- From
Derrick Stolee <stolee@gmail.com>
- Date
- Aug 25, 2021, 14:27 UTC
- Message-ID
- <fc0c8047-4d46-a349-88d3-f959c25de953@gmail.com>
- In-Reply-To
- <cover.1629800774.git.ps@pks.im>
On 8/24/2021 6:36 AM, Patrick Steinhardt wrote:
Show 20 quoted lines
> Changes compared to v1: > > - Patch 1/7: I've applied Stolee's proposal to only > opportunistically load objects via the commit-graph in case the > reference is not in refs/tags/ such that we don't regress repos > with many annotated tags. > > - Patch 3/7: The return parameter of the iterator is now const to > allow further optimizations by the compiler, as suggested by > René. I've also re-benchmarked this, and one can now see a very > slight performance improvement of ~1%. > > - Patch 4/7: Added my missing DCO, as pointed out by Junio. > > - Patch 5, 6, 7: I've redone these to make it clearer that the > refactoring I'm doing doesn't cause us to miss any object > connectivity checks. Most importantly, I've merged `fetch_refs()` > and `consume_refs()` into `fetch_and_consume_refs()` in 6/7, which > makes the optimization where we elide the second connectivity > check in 7/7 trivial.
These changes are positive. My read through this set of patches had only a few nit-picks.
Thanks, -Stolee